---WiXP Lib

I dont know what write there, but lib can:
- encode("Text to encode", Char.vocabulary)
- decode("Key what you get in encode", Char.vocabulary)
- and log (info("text", "level"), warn, error)
- and colorprint("text", "color")

  In 0.0.3 patch fixed non-importing error
